:html_theme.sidebar_secondary.remove:

.. _cotainr_documentation:

cotainr documentation
=====================

**Date**: |today| **Version**: |version|

**cotainr** - a user space `Apptainer`_/`Singularity`_ container builder.

.. toctree::
   :maxdepth: 1
   :hidden:
   :includehidden:

   Getting Started <getting_started>
   User Guide <user_guide/index>
   API reference <api_reference/index>
   Development <development/index>
   Release Notes <release_notes/index>

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: Getting Started
        :text-align: center
        :class-card: sd-rounded-0 sd-shadow-sm

        :material-outlined:`directions_run;5em;sd-text-info`

        Quickly get up and running with `cotainr`

        +++

        .. button-ref:: getting_started
            :expand:
            :color: secondary
            :click-parent:

            To the getting started guides

    .. grid-item-card:: User Guide
        :text-align: center
        :class-card: sd-rounded-0 sd-shadow-sm

        :material-outlined:`menu_book;5em;sd-text-info`

        In-depth information about ways to use `cotainr`

        +++

        .. button-ref:: user_guide/index
            :expand:
            :color: secondary
            :click-parent:

            To the user guide

    .. grid-item-card:: API reference
        :text-align: center
        :class-card: sd-rounded-0 sd-shadow-sm

        :material-outlined:`api;5em;sd-text-info`

        Detailed description of the `cotainr` Python API

        +++

        .. button-ref:: api_reference/index
            :expand:
            :color: secondary
            :click-parent:

            To the API reference guide

    .. grid-item-card:: Development
        :text-align: center
        :class-card: sd-rounded-0 sd-shadow-sm

        :material-outlined:`developer_mode;5em;sd-text-info`

        Guides for hacking on `cotainr`

        +++

        .. button-ref:: development/index
            :expand:
            :color: secondary
            :click-parent:

            To the development guide

.. _Apptainer: https://apptainer.org/
.. _Singularity: https://sylabs.io/singularity/
